# corva_assets
The Corva API is a powerful interface providing great flexibility and extensibility with Corva. Whether your needs are simple UI visualizations, data entry, replication/sync tasks, real-time stream processing, or complex machine learning CPU-intensive apps, the Corva API is the way to make it happen. Our concepts are split into three distinct silos: data apps, visualization apps, and a REST API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v2.146.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import corva_assets
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import corva_assets
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import corva_assets
from corva_assets.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = corva_assets.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api_key
configuration.api_key['api_key'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'


# Enter a context with an instance of the API client
with corva_assets.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = corva_assets.AssetsApi(api_client)
    id = 3.4 # float | Asset ID
    fields = ['fields_example'] # List[str] | Respond with only the given list of fields, like asset.asset_type (optional)

    try:
        # Get asset by ID
        api_response = api_instance.get_asset_by_id(id, fields=fields)
        print("The response of AssetsApi->get_asset_by_id:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AssetsApi->get_asset_by_id: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AssetsApi* | [**get_asset_by_id**](docs/AssetsApi.md#get_asset_by_id) | **GET** /v2/assets/{id} | Get asset by ID
*AssetsApi* | [**search_assets**](docs/AssetsApi.md#search_assets) | **GET** /v2/assets | List assets


## Documentation For Models

 - [Asset](docs/Asset.md)
 - [AssetAttributes](docs/AssetAttributes.md)
 - [AssetAttributesSourceWell](docs/AssetAttributesSourceWell.md)
 - [Assets](docs/Assets.md)
 - [AuthenticationError](docs/AuthenticationError.md)
 - [AuthorizationError](docs/AuthorizationError.md)
 - [NotFoundError](docs/NotFoundError.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="api_key"></a>
### api_key

- **Type**: API key
- **API key parameter name**: authorization
- **Location**: HTTP header


## Author

support@corva.ai


